@@ -1,14 +1,16 @@
+from __future__ import annotations
+
 import functools
 import io
 import os
 
-import numpy as np
 from packaging.version import Version
 
 from ..core import indexing
 from ..core.utils import (
     FrozenDict,
     is_remote_uri,
+    module_available,
     read_magic_number_from_file,
     try_read_magic_number_from_file_or_path,
 )
@@ -31,16 +33,6 @@ from .netCDF4_ import (
 )
 from .store import StoreBackendEntrypoint
 
-try:
-    import h5netcdf
-
-    has_h5netcdf = True
-except ImportError:
-    # Except a base ImportError (not ModuleNotFoundError) to catch usecases
-    # where errors have mismatched versions of c-dependencies. This can happen
-    # when developers are making changes them.
-    has_h5netcdf = False
-
 
 class H5NetCDFArrayWrapper(BaseNetCDF4Array):
     def get_array(self, needs_lock=True):
@@ -53,9 +45,6 @@ class H5NetCDFArrayWrapper(BaseNetCDF4Array):
         )
 
     def _getitem(self, key):
-        # h5py requires using lists for fancy indexing:
-        # https://github.com/h5py/h5py/issues/992
-        key = tuple(list(k) if isinstance(k, np.ndarray) else k for k in key)
         with self.datastore.lock:
             array = self.get_array(needs_lock=False)
             return array[key]
@@ -108,6 +97,7 @@ class H5NetCDFStore(WritableCFDataStore):
     )
 
     def __init__(self, manager, group=None, mode=None, lock=HDF5_LOCK, autoclose=False):
+        import h5netcdf
 
         if isinstance(manager, (h5netcdf.File, h5netcdf.Group)):
             if group is None:
@@ -145,6 +135,7 @@ class H5NetCDFStore(WritableCFDataStore):
         phony_dims=None,
         decode_vlen_strings=True,
     ):
+        import h5netcdf
 
         if isinstance(filename, bytes):
             raise ValueError(
@@ -235,12 +226,16 @@ class H5NetCDFStore(WritableCFDataStore):
         return FrozenDict(_read_attributes(self.ds))
 
     def get_dimensions(self):
+        import h5netcdf
+
         if Version(h5netcdf.__version__) >= Version("0.14.0.dev0"):
             return FrozenDict((k, len(v)) for k, v in self.ds.dimensions.items())
         else:
             return self.ds.dimensions
 
     def get_encoding(self):
+        import h5netcdf
+
         if Version(h5netcdf.__version__) >= Version("0.14.0.dev0"):
             return {
                 "unlimited_dims": {
@@ -280,7 +275,7 @@ class H5NetCDFStore(WritableCFDataStore):
             raise NotImplementedError(
                 "h5netcdf does not yet support setting a fill value for "
                 "variable-length strings "
-                "(https://github.com/shoyer/h5netcdf/issues/37). "
+                "(https://github.com/h5netcdf/h5netcdf/issues/37). "
                 f"Either remove '_FillValue' from encoding on variable {name!r} "
                 "or set {'dtype': 'S1'} in encoding to use the fixed width "
                 "NC_CHAR type."
@@ -350,7 +345,32 @@ class H5NetCDFStore(WritableCFDataStore):
 
 
 class H5netcdfBackendEntrypoint(BackendEntrypoint):
-    available = has_h5netcdf
+    """
+    Backend for netCDF files based on the h5netcdf package.
+
+    It can open ".nc", ".nc4", ".cdf" files but will only be
+    selected as the default if the "netcdf4" engine is not available.
+
+    Additionally it can open valid HDF5 files, see
+    https://h5netcdf.org/#invalid-netcdf-files for more info.
+    It will not be detected as valid backend for such files, so make
+    sure to specify ``engine="h5netcdf"`` in ``open_dataset``.
+
+    For more information about the underlying library, visit:
+    https://h5netcdf.org
+
+    See Also
+    --------
+    backends.H5NetCDFStore
+    backends.NetCDF4BackendEntrypoint
+    backends.ScipyBackendEntrypoint
+    """
+
+    available = module_available("h5netcdf")
+    description = (
+        "Open netCDF (.nc, .nc4 and .cdf) and most HDF5 files using h5netcdf in Xarray"
+    )
+    url = "https://docs.xarray.dev/en/stable/generated/xarray.backends.H5netcdfBackendEntrypoint.html"
 
     def guess_can_open(self, filename_or_obj):
         magic_number = try_read_magic_number_from_file_or_path(filename_or_obj)
