@@ -7,7 +7,7 @@ import pandas as pd
 from .coding import strings, times, variables
 from .coding.variables import SerializationWarning, pop_to
 from .core import duck_array_ops, indexing
-from .core.common import contains_cftime_datetimes
+from .core.common import _contains_datetime_like_objects, contains_cftime_datetimes
 from .core.pycompat import is_duck_dask_array
 from .core.variable import IndexVariable, Variable, as_variable
 
@@ -141,7 +141,7 @@ def maybe_encode_bools(var):
     ):
         dims, data, attrs, encoding = _var_as_tuple(var)
         attrs["dtype"] = "bool"
-        data = data.astype(dtype="i1", copy=True)
+        data = duck_array_ops.astype(data, dtype="i1", copy=True)
         var = Variable(dims, data, attrs, encoding)
     return var
 
@@ -340,6 +340,11 @@ def decode_cf_variable(
         A variable holding the decoded equivalent of var.
     """
     var = as_variable(var)
+
+    # Ensure datetime-like Variables are passed through unmodified (GH 6453)
+    if _contains_datetime_like_objects(var):
+        return var
+
     original_dtype = var.dtype
 
     if decode_timedelta is None:
@@ -402,7 +407,8 @@ def _update_bounds_attributes(variables):
     # For all time variables with bounds
     for v in variables.values():
         attrs = v.attrs
-        has_date_units = "units" in attrs and "since" in attrs["units"]
+        units = attrs.get("units")
+        has_date_units = isinstance(units, str) and "since" in units
         if has_date_units and "bounds" in attrs:
             if attrs["bounds"] in variables:
                 bounds_attrs = variables[attrs["bounds"]].attrs
@@ -513,16 +519,19 @@ def decode_cf_variables(
             and v.ndim > 0
             and stackable(v.dims[-1])
         )
-        new_vars[k] = decode_cf_variable(
-            k,
-            v,
-            concat_characters=concat_characters,
-            mask_and_scale=mask_and_scale,
-            decode_times=decode_times,
-            stack_char_dim=stack_char_dim,
-            use_cftime=use_cftime,
-            decode_timedelta=decode_timedelta,
-        )
+        try:
+            new_vars[k] = decode_cf_variable(
+                k,
+                v,
+                concat_characters=concat_characters,
+                mask_and_scale=mask_and_scale,
+                decode_times=decode_times,
+                stack_char_dim=stack_char_dim,
+                use_cftime=use_cftime,
+                decode_timedelta=decode_timedelta,
+            )
+        except Exception as e:
+            raise type(e)(f"Failed to decode variable {k!r}: {e}")
         if decode_coords in [True, "coordinates", "all"]:
             var_attrs = new_vars[k].attrs
             if "coordinates" in var_attrs:
@@ -770,7 +779,7 @@ def _encode_coordinates(variables, attributes, non_dim_coord_names):
         # this will copy coordinates from encoding to attrs if "coordinates" in attrs
         # after the next line, "coordinates" is never in encoding
         # we get support for attrs["coordinates"] for free.
-        coords_str = pop_to(encoding, attrs, "coordinates")
+        coords_str = pop_to(encoding, attrs, "coordinates") or attrs.get("coordinates")
         if not coords_str and variable_coordinates[name]:
             coordinates_text = " ".join(
                 str(coord_name)
