@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import copy
+from datetime import datetime
 from typing import Any
 
 import numpy as np
@@ -8,16 +9,20 @@ import pandas as pd
 import pytest
 
 import xarray as xr
+from xarray.coding.cftimeindex import CFTimeIndex
 from xarray.core.indexes import (
+    Hashable,
     Index,
     Indexes,
     PandasIndex,
     PandasMultiIndex,
     _asarray_tuplesafe,
+    safe_cast_to_index,
 )
 from xarray.core.variable import IndexVariable, Variable
 
-from . import assert_identical
+from . import assert_array_equal, assert_identical, requires_cftime
+from .test_coding_times import _all_cftime_date_types
 
 
 def test_asarray_tuplesafe() -> None:
@@ -44,7 +49,7 @@ class TestIndex:
 
     def test_from_variables(self) -> None:
         with pytest.raises(NotImplementedError):
-            Index.from_variables({})
+            Index.from_variables({}, options={})
 
     def test_concat(self) -> None:
         with pytest.raises(NotImplementedError):
@@ -132,19 +137,19 @@ class TestPandasIndex:
             "x", data, attrs={"unit": "m"}, encoding={"dtype": np.float64}
         )
 
-        index = PandasIndex.from_variables({"x": var})
+        index = PandasIndex.from_variables({"x": var}, options={})
         assert index.dim == "x"
         assert index.index.equals(pd.Index(data))
         assert index.coord_dtype == data.dtype
 
         var2 = xr.Variable(("x", "y"), [[1, 2, 3], [4, 5, 6]])
         with pytest.raises(ValueError, match=r".*only accepts one variable.*"):
-            PandasIndex.from_variables({"x": var, "foo": var2})
+            PandasIndex.from_variables({"x": var, "foo": var2}, options={})
 
         with pytest.raises(
             ValueError, match=r".*only accepts a 1-dimensional variable.*"
         ):
-            PandasIndex.from_variables({"foo": var2})
+            PandasIndex.from_variables({"foo": var2}, options={})
 
     def test_from_variables_index_adapter(self) -> None:
         # test index type is preserved when variable wraps a pd.Index
@@ -152,7 +157,7 @@ class TestPandasIndex:
         pd_idx = pd.Index(data)
         var = xr.Variable("x", pd_idx)
 
-        index = PandasIndex.from_variables({"x": var})
+        index = PandasIndex.from_variables({"x": var}, options={})
         assert isinstance(index.index, pd.CategoricalIndex)
 
     def test_concat_periods(self):
@@ -264,13 +269,13 @@ class TestPandasIndex:
         actual = index1.join(index2)
         print(actual.index)
         assert actual.equals(expected)
-        assert actual.coord_dtype == "<U4"
+        assert actual.coord_dtype == "=U4"
 
         expected = PandasIndex(["a", "aa", "aaa", "aaaa"], "x")
         actual = index1.join(index2, how="outer")
         print(actual.index)
         assert actual.equals(expected)
-        assert actual.coord_dtype == "<U4"
+        assert actual.coord_dtype == "=U4"
 
     def test_reindex_like(self) -> None:
         index1 = PandasIndex([0, 1, 2], "x")
@@ -355,7 +360,7 @@ class TestPandasMultiIndex:
         )
 
         index = PandasMultiIndex.from_variables(
-            {"level1": v_level1, "level2": v_level2}
+            {"level1": v_level1, "level2": v_level2}, options={}
         )
 
         expected_idx = pd.MultiIndex.from_arrays([v_level1.data, v_level2.data])
@@ -368,19 +373,21 @@ class TestPandasMultiIndex:
         with pytest.raises(
             ValueError, match=r".*only accepts 1-dimensional variables.*"
         ):
-            PandasMultiIndex.from_variables({"var": var})
+            PandasMultiIndex.from_variables({"var": var}, options={})
 
         v_level3 = xr.Variable("y", [4, 5, 6])
         with pytest.raises(
             ValueError, match=r"unmatched dimensions for multi-index variables.*"
         ):
-            PandasMultiIndex.from_variables({"level1": v_level1, "level3": v_level3})
+            PandasMultiIndex.from_variables(
+                {"level1": v_level1, "level3": v_level3}, options={}
+            )
 
     def test_concat(self) -> None:
         pd_midx = pd.MultiIndex.from_product(
             [[0, 1, 2], ["a", "b"]], names=("foo", "bar")
         )
-        level_coords_dtype = {"foo": np.int32, "bar": "<U1"}
+        level_coords_dtype = {"foo": np.int32, "bar": "=U1"}
 
         midx1 = PandasMultiIndex(
             pd_midx[:2], "x", level_coords_dtype=level_coords_dtype
@@ -484,7 +491,7 @@ class TestPandasMultiIndex:
 
     def test_join(self):
         midx = pd.MultiIndex.from_product([["a", "aa"], [1, 2]], names=("one", "two"))
-        level_coords_dtype = {"one": "<U2", "two": "i"}
+        level_coords_dtype = {"one": "=U2", "two": "i"}
         index1 = PandasMultiIndex(midx, "x", level_coords_dtype=level_coords_dtype)
         index2 = PandasMultiIndex(midx[0:2], "x", level_coords_dtype=level_coords_dtype)
 
@@ -535,7 +542,7 @@ class TestPandasMultiIndex:
 
 class TestIndexes:
     @pytest.fixture
-    def unique_indexes(self) -> list[PandasIndex]:
+    def indexes_and_vars(self) -> tuple[list[PandasIndex], dict[Hashable, Variable]]:
         x_idx = PandasIndex(pd.Index([1, 2, 3], name="x"), "x")
         y_idx = PandasIndex(pd.Index([4, 5, 6], name="y"), "y")
         z_pd_midx = pd.MultiIndex.from_product(
@@ -543,10 +550,29 @@ class TestIndexes:
         )
         z_midx = PandasMultiIndex(z_pd_midx, "z")
 
-        return [x_idx, y_idx, z_midx]
+        indexes = [x_idx, y_idx, z_midx]
+
+        variables = {}
+        for idx in indexes:
+            variables.update(idx.create_variables())
+
+        return indexes, variables
+
+    @pytest.fixture(params=["pd_index", "xr_index"])
+    def unique_indexes(
+        self, request, indexes_and_vars
+    ) -> list[PandasIndex] | list[pd.Index]:
+        xr_indexes, _ = indexes_and_vars
+
+        if request.param == "pd_index":
+            return [idx.index for idx in xr_indexes]
+        else:
+            return xr_indexes
 
     @pytest.fixture
-    def indexes(self, unique_indexes) -> Indexes[Index]:
+    def indexes(
+        self, unique_indexes, indexes_and_vars
+    ) -> Indexes[Index] | Indexes[pd.Index]:
         x_idx, y_idx, z_midx = unique_indexes
         indexes: dict[Any, Index] = {
             "x": x_idx,
@@ -555,9 +581,8 @@ class TestIndexes:
             "one": z_midx,
             "two": z_midx,
         }
-        variables: dict[Any, Variable] = {}
-        for idx in unique_indexes:
-            variables.update(idx.create_variables())
+
+        _, variables = indexes_and_vars
 
         return Indexes(indexes, variables)
 
@@ -635,3 +660,41 @@ class TestIndexes:
         assert index_vars.keys() == indexes.variables.keys()
         for new, original in zip(index_vars.values(), indexes.variables.values()):
             assert_identical(new, original)
+
+
+def test_safe_cast_to_index():
+    dates = pd.date_range("2000-01-01", periods=10)
+    x = np.arange(5)
+    td = x * np.timedelta64(1, "D")
+    for expected, array in [
+        (dates, dates.values),
+        (pd.Index(x, dtype=object), x.astype(object)),
+        (pd.Index(td), td),
+        (pd.Index(td, dtype=object), td.astype(object)),
+    ]:
+        actual = safe_cast_to_index(array)
+        assert_array_equal(expected, actual)
+        assert expected.dtype == actual.dtype
+
+
+@requires_cftime
+def test_safe_cast_to_index_cftimeindex():
+    date_types = _all_cftime_date_types()
+    for date_type in date_types.values():
+        dates = [date_type(1, 1, day) for day in range(1, 20)]
+        expected = CFTimeIndex(dates)
+        actual = safe_cast_to_index(np.array(dates))
+        assert_array_equal(expected, actual)
+        assert expected.dtype == actual.dtype
+        assert isinstance(actual, type(expected))
+
+
+# Test that datetime.datetime objects are never used in a CFTimeIndex
+@requires_cftime
+def test_safe_cast_to_index_datetime_datetime():
+    dates = [datetime(1, 1, day) for day in range(1, 20)]
+
+    expected = pd.Index(dates)
+    actual = safe_cast_to_index(np.array(dates))
+    assert_array_equal(expected, actual)
+    assert isinstance(actual, pd.Index)
