@@ -11,7 +11,7 @@ from packaging.version import Version
 
 import xarray as xr
 from xarray import DataArray, Variable
-from xarray.core.pycompat import sparse_array_type, sparse_version
+from xarray.core.pycompat import array_type, mod_version
 
 from . import assert_equal, assert_identical, requires_dask
 
@@ -20,6 +20,8 @@ param = pytest.param
 xfail = pytest.mark.xfail
 
 sparse = pytest.importorskip("sparse")
+sparse_array_type = array_type("sparse")
+sparse_version = mod_version("sparse")
 
 
 def assert_sparse_equal(a, b):
@@ -274,6 +276,9 @@ class TestSparseVariable:
         self.data = sparse.random((4, 6), random_state=0, density=0.5)
         self.var = xr.Variable(("x", "y"), self.data)
 
+    def test_nbytes(self):
+        assert self.var.nbytes == self.data.nbytes
+
     def test_unary_op(self):
         assert_sparse_equal(-self.var.data, -self.data)
         assert_sparse_equal(abs(self.var).data, abs(self.data))
