@@ -1,31 +1,33 @@
 from __future__ import annotations
 
+from typing import Any, Iterable
+
 import numpy as np
 import pytest
 
 import xarray as xr
-from xarray import DataArray
+from xarray import DataArray, Dataset
 from xarray.tests import assert_allclose, assert_equal
 
 from . import raise_if_dask_computes, requires_cftime, requires_dask
 
 
 @pytest.mark.parametrize("as_dataset", (True, False))
-def test_weighted_non_DataArray_weights(as_dataset):
+def test_weighted_non_DataArray_weights(as_dataset: bool) -> None:
 
-    data = DataArray([1, 2])
+    data: DataArray | Dataset = DataArray([1, 2])
     if as_dataset:
         data = data.to_dataset(name="data")
 
     with pytest.raises(ValueError, match=r"`weights` must be a DataArray"):
-        data.weighted([1, 2])
+        data.weighted([1, 2])  # type: ignore
 
 
 @pytest.mark.parametrize("as_dataset", (True, False))
 @pytest.mark.parametrize("weights", ([np.nan, 2], [np.nan, np.nan]))
-def test_weighted_weights_nan_raises(as_dataset, weights):
+def test_weighted_weights_nan_raises(as_dataset: bool, weights: list[float]) -> None:
 
-    data = DataArray([1, 2])
+    data: DataArray | Dataset = DataArray([1, 2])
     if as_dataset:
         data = data.to_dataset(name="data")
 
@@ -269,22 +271,30 @@ def test_weighted_quantile_nan(skipna):
 @pytest.mark.parametrize(
     "da",
     (
-        [1, 1.9, 2.2, 3, 3.7, 4.1, 5],
-        [1, 1.9, 2.2, 3, 3.7, 4.1, np.nan],
-        [np.nan, np.nan, np.nan],
+        pytest.param([1, 1.9, 2.2, 3, 3.7, 4.1, 5], id="nonan"),
+        pytest.param([1, 1.9, 2.2, 3, 3.7, 4.1, np.nan], id="singlenan"),
+        pytest.param(
+            [np.nan, np.nan, np.nan],
+            id="allnan",
+            marks=pytest.mark.filterwarnings(
+                "ignore:All-NaN slice encountered:RuntimeWarning"
+            ),
+        ),
     ),
 )
 @pytest.mark.parametrize("q", (0.5, (0.2, 0.8)))
 @pytest.mark.parametrize("skipna", (True, False))
 @pytest.mark.parametrize("factor", [1, 3.14])
-def test_weighted_quantile_equal_weights(da, q, skipna, factor):
+def test_weighted_quantile_equal_weights(
+    da: list[float], q: float | tuple[float, ...], skipna: bool, factor: float
+) -> None:
     # if all weights are equal (!= 0), should yield the same result as quantile
 
-    da = DataArray(da)
-    weights = xr.full_like(da, factor)
+    data = DataArray(da)
+    weights = xr.full_like(data, factor)
 
-    expected = da.quantile(q, skipna=skipna)
-    result = da.weighted(weights).quantile(q, skipna=skipna)
+    expected = data.quantile(q, skipna=skipna)
+    result = data.weighted(weights).quantile(q, skipna=skipna)
 
     assert_allclose(expected, result)
 
@@ -654,23 +664,49 @@ def test_weighted_quantile_3D(dim, q, add_nans, skipna):
     assert_allclose(expected, result2.data)
 
 
-def test_weighted_operations_nonequal_coords():
-    # There are no weights for a == 4, so that data point is ignored.
-    weights = DataArray(np.random.randn(4), dims=("a",), coords=dict(a=[0, 1, 2, 3]))
-    data = DataArray(np.random.randn(4), dims=("a",), coords=dict(a=[1, 2, 3, 4]))
-    check_weighted_operations(data, weights, dim="a", skipna=None)
+@pytest.mark.parametrize(
+    "coords_weights, coords_data, expected_value_at_weighted_quantile",
+    [
+        ([0, 1, 2, 3], [1, 2, 3, 4], 2.5),  # no weights for coord a == 4
+        ([0, 1, 2, 3], [2, 3, 4, 5], 1.8),  # no weights for coord a == 4 or 5
+        ([2, 3, 4, 5], [0, 1, 2, 3], 3.8),  # no weights for coord a == 0 or 1
+    ],
+)
+def test_weighted_operations_nonequal_coords(
+    coords_weights: Iterable[Any],
+    coords_data: Iterable[Any],
+    expected_value_at_weighted_quantile: float,
+) -> None:
+    """Check that weighted operations work with unequal coords.
 
-    q = 0.5
-    result = data.weighted(weights).quantile(q, dim="a")
-    # Expected value computed using code from https://aakinshin.net/posts/weighted-quantiles/ with values at a=1,2,3
-    expected = DataArray([0.9308707], coords={"quantile": [q]}).squeeze()
-    assert_allclose(result, expected)
 
-    data = data.to_dataset(name="data")
-    check_weighted_operations(data, weights, dim="a", skipna=None)
+    Parameters
+    ----------
+    coords_weights : Iterable[Any]
+        The coords for the weights.
+    coords_data : Iterable[Any]
+        The coords for the data.
+    expected_value_at_weighted_quantile : float
+        The expected value for the quantile of the weighted data.
+    """
+    da_weights = DataArray(
+        [0.5, 1.0, 1.0, 2.0], dims=("a",), coords=dict(a=coords_weights)
+    )
+    da_data = DataArray([1, 2, 3, 4], dims=("a",), coords=dict(a=coords_data))
+    check_weighted_operations(da_data, da_weights, dim="a", skipna=None)
 
-    result = data.weighted(weights).quantile(q, dim="a")
-    assert_allclose(result, expected.to_dataset(name="data"))
+    quantile = 0.5
+    da_actual = da_data.weighted(da_weights).quantile(quantile, dim="a")
+    da_expected = DataArray(
+        [expected_value_at_weighted_quantile], coords={"quantile": [quantile]}
+    ).squeeze()
+    assert_allclose(da_actual, da_expected)
+
+    ds_data = da_data.to_dataset(name="data")
+    check_weighted_operations(ds_data, da_weights, dim="a", skipna=None)
+
+    ds_actual = ds_data.weighted(da_weights).quantile(quantile, dim="a")
+    assert_allclose(ds_actual, da_expected.to_dataset(name="data"))
 
 
 @pytest.mark.parametrize("shape_data", ((4,), (4, 4), (4, 4, 4)))
