@@ -5,8 +5,12 @@ Useful for:
 * building tutorials in the documentation.
 
 """
+from __future__ import annotations
+
 import os
 import pathlib
+import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 
@@ -15,6 +19,10 @@ from .backends.rasterio_ import open_rasterio as _open_rasterio
 from .core.dataarray import DataArray
 from .core.dataset import Dataset
 
+if TYPE_CHECKING:
+    from .backends.api import T_Engine
+
+
 _default_cache_dir_name = "xarray_tutorial_data"
 base_url = "https://github.com/pydata/xarray-data"
 version = "master"
@@ -33,11 +41,15 @@ def _construct_cache_dir(path):
 
 external_urls = {}  # type: dict
 external_rasterio_urls = {
-    "RGB.byte": "https://github.com/mapbox/rasterio/raw/1.2.1/tests/data/RGB.byte.tif",
-    "shade": "https://github.com/mapbox/rasterio/raw/1.2.1/tests/data/shade.tif",
+    "RGB.byte": "https://github.com/rasterio/rasterio/raw/1.2.1/tests/data/RGB.byte.tif",
+    "shade": "https://github.com/rasterio/rasterio/raw/1.2.1/tests/data/shade.tif",
 }
 file_formats = {
     "air_temperature": 3,
+    "air_temperature_gradient": 4,
+    "ASE_ice_velocity": 4,
+    "basin_mask": 4,
+    "ersstv5": 4,
     "rasm": 3,
     "ROMS_example": 4,
     "tiny": 3,
@@ -73,13 +85,13 @@ def _check_netcdf_engine_installed(name):
 
 # idea borrowed from Seaborn
 def open_dataset(
-    name,
-    cache=True,
-    cache_dir=None,
+    name: str,
+    cache: bool = True,
+    cache_dir: None | str | os.PathLike = None,
     *,
-    engine=None,
+    engine: T_Engine = None,
     **kws,
-):
+) -> Dataset:
     """
     Open a dataset from the online repository (requires internet).
 
@@ -88,11 +100,15 @@ def open_dataset(
     Available datasets:
 
     * ``"air_temperature"``: NCEP reanalysis subset
+    * ``"air_temperature_gradient"``: NCEP reanalysis subset with approximate x,y gradients
+    * ``"basin_mask"``: Dataset with ocean basins marked using integers
+    * ``"ASE_ice_velocity"``: MEaSUREs InSAR-Based Ice Velocity of the Amundsen Sea Embayment, Antarctica, Version 1
     * ``"rasm"``: Output of the Regional Arctic System Model (RASM)
     * ``"ROMS_example"``: Regional Ocean Model System (ROMS) output
     * ``"tiny"``: small synthetic dataset with a 1D data variable
     * ``"era5-2mt-2019-03-uk.grib"``: ERA5 temperature data over the UK
     * ``"eraint_uvz"``: data from ERA-Interim reanalysis, monthly averages of upper level data
+    * ``"ersstv5"``: NOAA's Extended Reconstructed Sea Surface Temperature monthly averages
 
     Parameters
     ----------
@@ -108,7 +124,9 @@ def open_dataset(
 
     See Also
     --------
-    xarray.open_dataset
+    tutorial.load_dataset
+    open_dataset
+    load_dataset
     """
     try:
         import pooch
@@ -158,6 +176,12 @@ def open_rasterio(
     """
     Open a rasterio dataset from the online repository (requires internet).
 
+    .. deprecated:: 0.20.0
+
+        Deprecated in favor of rioxarray.
+        For information about transitioning, see:
+        https://corteva.github.io/rioxarray/stable/getting_started/getting_started.html
+
     If a local copy is found then always use that to avoid network traffic.
 
     Available datasets:
@@ -185,8 +209,15 @@ def open_rasterio(
 
     References
     ----------
-    .. [1] https://github.com/mapbox/rasterio
+    .. [1] https://github.com/rasterio/rasterio
     """
+    warnings.warn(
+        "open_rasterio is Deprecated in favor of rioxarray. "
+        "For information about transitioning, see: "
+        "https://corteva.github.io/rioxarray/stable/getting_started/getting_started.html",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         import pooch
     except ImportError as e:
@@ -213,20 +244,48 @@ def open_rasterio(
     return arr
 
 
-def load_dataset(*args, **kwargs):
+def load_dataset(*args, **kwargs) -> Dataset:
     """
     Open, load into memory, and close a dataset from the online repository
     (requires internet).
 
+    If a local copy is found then always use that to avoid network traffic.
+
+    Available datasets:
+
+    * ``"air_temperature"``: NCEP reanalysis subset
+    * ``"air_temperature_gradient"``: NCEP reanalysis subset with approximate x,y gradients
+    * ``"basin_mask"``: Dataset with ocean basins marked using integers
+    * ``"rasm"``: Output of the Regional Arctic System Model (RASM)
+    * ``"ROMS_example"``: Regional Ocean Model System (ROMS) output
+    * ``"tiny"``: small synthetic dataset with a 1D data variable
+    * ``"era5-2mt-2019-03-uk.grib"``: ERA5 temperature data over the UK
+    * ``"eraint_uvz"``: data from ERA-Interim reanalysis, monthly averages of upper level data
+    * ``"ersstv5"``: NOAA's Extended Reconstructed Sea Surface Temperature monthly averages
+
+    Parameters
+    ----------
+    name : str
+        Name of the file containing the dataset.
+        e.g. 'air_temperature'
+    cache_dir : path-like, optional
+        The directory in which to search for and write cached data.
+    cache : bool, optional
+        If True, then cache data locally for use on subsequent calls
+    **kws : dict, optional
+        Passed to xarray.open_dataset
+
     See Also
     --------
+    tutorial.open_dataset
     open_dataset
+    load_dataset
     """
     with open_dataset(*args, **kwargs) as ds:
         return ds.load()
 
 
-def scatter_example_dataset(*, seed=None) -> Dataset:
+def scatter_example_dataset(*, seed: None | int = None) -> Dataset:
     """
     Create an example dataset.
 
